@@ -2,11 +2,13 @@ from enum import Enum
 from typing import Optional
 
 from rich.traceback import install
-from typer import Argument, Option, Typer
+from typer import Argument, Exit, Option, Typer, echo
 
 from weather_command._builder import show_current, show_daily, show_hourly
 from weather_command._cache import Cache
 
+__version__ = "2.1.1"
+
 install()
 app = Typer()
 
@@ -22,6 +24,12 @@ class How(str, Enum):
     ZIP = "zip"
 
 
+def version_callback(value: bool) -> None:
+    if value:
+        echo(__version__)
+        raise Exit()
+
+
 @app.command()
 def main(
     how: How = Argument(
@@ -65,6 +73,14 @@ def main(
     terminal_width: Optional[int] = Option(
         None, help="Allows for overriding the default terminal width."
     ),
+    version: Optional[bool] = Option(
+        None,
+        "--version",
+        "-v",
+        callback=version_callback,
+        is_eager=True,
+        help="Show the installed weather command version",
+    ),
 ) -> None:
     if clear_cache:
         cache = Cache()
